@@ -64,7 +64,7 @@ remove_directory (GFile *directory)
     GFileInfo *info;
 
     while ((info = g_file_enumerator_next_file (enumerator, NULL, NULL)) != NULL) {
-      g_autoptr (GFile) child;
+      g_autoptr (GFile) child = NULL;
 
       child = g_file_get_child (directory, g_file_info_get_name (info));
 
@@ -334,8 +334,8 @@ scan_directory (GFile *directory,
                                         NULL, NULL));
 
   while (!g_queue_is_empty (files)) {
-    g_autoptr (GFile) file;
-    g_autoptr (GFileInfo) file_info;
+    g_autoptr (GFile) file = NULL;
+    g_autoptr (GFileInfo) file_info = NULL;
 
     file = g_queue_pop_tail (files);
     file_info = g_queue_pop_tail (file_infos);
@@ -398,7 +398,7 @@ reference_file_scanned (GFile *scanned_file,
                         gpointer user_data)
 {
   ExtractTest *extract_test = user_data;
-  g_autofree char *relative_path;
+  g_autofree char *relative_path = NULL;
   GFileInfo *corresponding_file_info;
 
   relative_path = scanned_file == extract_test->reference ?
@@ -653,6 +653,90 @@ test_multiple_files_different_name (void)
   assert_reference_and_output_match (extract_test);
 }
 
+static void
+test_raw_named (void)
+{
+  /* arextract.gz
+   * └── arextractdifferent
+   *
+   * 0 directories, 1 file
+   *
+   *
+   * ref
+   * └── arextractdifferent
+   *
+   * 0 directories, 1 file
+   */
+
+  g_autoptr (ExtractTest) extract_test = NULL;
+  g_autoptr (ExtractTestData) data = NULL;
+  g_autoptr (GFile) archive = NULL;
+  g_autoptr (AutoarExtractor) extractor = NULL;
+
+  extract_test = extract_test_new ("test-raw-named");
+
+  if (!extract_test) {
+    g_assert_nonnull (extract_test);
+    return;
+  }
+
+  archive = g_file_get_child (extract_test->input, "arextract.gz");
+
+  extractor = autoar_extractor_new (archive, extract_test->output);
+  autoar_extractor_set_output_is_dest (extractor, TRUE);
+
+  data = extract_test_data_new_for_extract (extractor);
+
+  autoar_extractor_start (extractor, data->cancellable);
+
+  g_assert_cmpuint (data->number_of_files, ==, 1);
+  g_assert_no_error (data->error);
+  g_assert_true (data->completed_signalled);
+  assert_reference_and_output_match (extract_test);
+}
+
+static void
+test_raw_unnamed (void)
+{
+  /* arextract.gz
+   * └── arextract
+   *
+   * 0 directories, 1 file
+   *
+   *
+   * ref
+   * └── arextract
+   *
+   * 0 directories, 1 file
+   */
+
+  g_autoptr (ExtractTest) extract_test = NULL;
+  g_autoptr (ExtractTestData) data = NULL;
+  g_autoptr (GFile) archive = NULL;
+  g_autoptr (AutoarExtractor) extractor = NULL;
+
+  extract_test = extract_test_new ("test-raw-unnamed");
+
+  if (!extract_test) {
+    g_assert_nonnull (extract_test);
+    return;
+  }
+
+  archive = g_file_get_child (extract_test->input, "arextract.gz");
+
+  extractor = autoar_extractor_new (archive, extract_test->output);
+  autoar_extractor_set_output_is_dest (extractor, TRUE);
+
+  data = extract_test_data_new_for_extract (extractor);
+
+  autoar_extractor_start (extractor, data->cancellable);
+
+  g_assert_cmpuint (data->number_of_files, ==, 1);
+  g_assert_no_error (data->error);
+  g_assert_true (data->completed_signalled);
+  assert_reference_and_output_match (extract_test);
+}
+
 static void
 test_conflict_overwrite (void)
 {
@@ -1264,6 +1348,7 @@ test_readonly_directory (void)
   g_autoptr (ExtractTest) extract_test = NULL;
   g_autoptr (ExtractTestData) data = NULL;
   g_autoptr (GFile) archive = NULL;
+  g_autoptr (GFile) readonly = NULL;
   g_autoptr (AutoarExtractor) extractor = NULL;
 
   extract_test = extract_test_new ("test-readonly-directory");
@@ -1285,6 +1370,11 @@ test_readonly_directory (void)
   g_assert_no_error (data->error);
   g_assert_true (data->completed_signalled);
   assert_reference_and_output_match (extract_test);
+
+  /* Make the directory writable again to avoid issues when deleting. */
+  readonly = g_file_get_child (extract_test->output, "arextract");
+  g_file_set_attribute_uint32 (readonly, G_FILE_ATTRIBUTE_UNIX_MODE, 0755,
+                               G_FILE_QUERY_INFO_NONE, NULL, NULL);
 }
 
 static void
@@ -1301,6 +1391,11 @@ setup_test_suite (void)
   g_test_add_func ("/autoar-extract/test-multiple-files-different-name",
                    test_multiple_files_different_name);
 
+  g_test_add_func ("/autoar-extract/test-raw-named",
+                   test_raw_named);
+  g_test_add_func ("/autoar-extract/test-raw-unnamed",
+                   test_raw_unnamed);
+
   g_test_add_func ("/autoar-extract/test-conflict-overwrite",
                    test_conflict_overwrite);
   g_test_add_func ("/autoar-extract/test-conflict-overwrite-nonempty-directory",
